<?php
// $Id: media_pbs.variables.inc,v 1.1 2011/01/21 17:18:12 aaron Exp $

/**
 * @file Contains the variables and defaults used by Media: PBS.
 */

/**
 * The variable namespace for Media: PBS.
 */
define('MEDIA_PBS_NAMESPACE', 'media_pbs__');

/**
 * This is the main URL for PBS.
 */
define('MEDIA_PBS_MAIN_URL', 'http://pbs.org/');

/**
 * This is the URL to the API of PBS.
 */
define('MEDIA_PBS_API_INFO', 'http://projects.pbs.org/confluence/display/PX/Video+and+Other+Streaming+Media');

/**
 * This defines the version of the content data array that we serialize
 * in emvideo_pbs_data(). If we change the expected keys of that array,
 * we must increment this value, which will allow older content to be updated
 * to the new version automatically.
 */
define('MEDIA_PBS_DATA_VERSION', 1);

/**
 * Wrapper for variable_get() that uses the Media: PBS variable registry.
 *
 * @param string $name
 *  The variable name to retrieve. Note that it will be namespaced by
 *  pre-pending MEDIA_PBS_NAMESPACE, as to avoid variable collisions
 *  with other modules.
 * @param unknown $default
 *  An optional default variable to return if the variable hasn't been set
 *  yet. Note that within this module, all variables should already be set
 *  in the media_pbs_variable_default() function.
 * @return unknown
 *  Returns the stored variable or its default.
 *
 * @see media_pbs_variable_set()
 * @see media_pbs_variable_del()
 * @see media_pbs_variable_default()
 */
function media_pbs_variable_get($name, $default = NULL) {
  // Allow for an override of the default.
  // Useful when a variable is required (like $path), but namespacing still desired.
  if (!isset($default)) {
    $default = media_pbs_variable_default($name);
  }
  // Namespace all variables
  $variable_name = MEDIA_PBS_NAMESPACE . $name;
  return variable_get($variable_name, $default);
}

/**
 * Wrapper for variable_set() that uses the Media: PBS variable registry.
 *
 * @param string $name
 *  The variable name to set. Note that it will be namespaced by
 *  pre-pending MEDIA_PBS_NAMESPACE, as to avoid variable collisions with
 *  other modules.
 * @param unknown $value
 *  The value for which to set the variable.
 * @return unknown
 *  Returns the stored variable after setting.
 *
 * @see media_pbs_variable_get()
 * @see media_pbs_variable_del()
 * @see media_pbs_variable_default()
 */
function media_pbs_variable_set($name, $value) {
  $variable_name = MEDIA_PBS_NAMESPACE . $name;
  return variable_set($variable_name, $value);
}

/**
 * Wrapper for variable_del() that uses the Media: PBS variable registry.
 *
 * @param string $name
 *  The variable name to delete. Note that it will be namespaced by
 *  pre-pending MEDIA_PBS_NAMESPACE, as to avoid variable collisions with
 *  other modules.
 *
 * @see media_pbs_variable_get()
 * @see media_pbs_variable_set()
 * @see media_pbs_variable_default()
 */
function media_pbs_variable_del($name) {
  $variable_name = MEDIA_PBS_NAMESPACE . $name;
  variable_del($variable_name);
}

/**
 * The default variables within the Media: PBS namespace.
 *
 * @param string $name
 *  Optional variable name to retrieve the default. Note that it has not yet
 *  been pre-pended with the MEDIA_PBS_NAMESPACE namespace at this time.
 * @return unknown
 *  The default value of this variable, if it's been set, or NULL, unless
 *  $name is NULL, in which case we return an array of all default values.
 *
 * @see media_pbs_variable_get()
 * @see media_pbs_variable_set()
 * @see media_pbs_variable_del()
 */
function media_pbs_variable_default($name = NULL) {
  static $defaults;

  if (!isset($defaults)) {
    $defaults = array(
      'iframe' => TRUE,
      'chapterbar' => TRUE,
      'adjust_for_chapterbar' => FALSE,
      'chapter' => 1,
      'fullscreen' => TRUE,
      'width' => 512,
      'height' => 288,
      'chapterbar_height' => 40,
      'frameborder' => 0,
      'marginwidth' => 0,
      'marginheight' => 0,
      'scrolling' => FALSE,
      'autoplay' => FALSE,
    );
  }

  if (!isset($name)) {
    return $defaults;
  }

  if (isset($defaults[$name])) {
    return $defaults[$name];
  }
}

/**
 * Return the fully namespace variable name.
 *
 * @param string $name
 *  The variable name to retrieve the namespaced name.
 * @return string
 *  The fully namespace variable name, prepended with
 *  MEDIA_PBS_NAMESPACE.
 */
function media_pbs_variable_name($name) {
  return MEDIA_PBS_NAMESPACE . $name;
}
